@@ -12,7 +12,9 @@ from botorch.models.cost import AffineFidelityCostModel
 from botorch.models.deterministic import (
     AffineDeterministicModel,
     GenericDeterministicModel,
+    PosteriorMeanModel,
 )
+from botorch.models.fully_bayesian import SaasFullyBayesianSingleTaskGP
 from botorch.models.gp_regression import (
     FixedNoiseGP,
     HeteroskedasticSingleTaskGP,
@@ -36,6 +38,7 @@ __all__ = [
     "ApproximateGPyTorchModel",
     "FixedNoiseGP",
     "FixedNoiseMultiTaskGP",
+    "SaasFullyBayesianSingleTaskGP",
     "GenericDeterministicModel",
     "HeteroskedasticSingleTaskGP",
     "HigherOrderGP",
@@ -46,6 +49,7 @@ __all__ = [
     "MultiTaskGP",
     "PairwiseGP",
     "PairwiseLaplaceMarginalLogLikelihood",
+    "PosteriorMeanModel",
     "SingleTaskGP",
     "SingleTaskMultiFidelityGP",
     "SingleTaskVariationalGP",
