@@ -36,7 +36,6 @@ from botorch.posteriors.gpytorch import GPyTorchPosterior
 from botorch.utils.transforms import is_fully_bayesian
 from gpytorch.distributions import MultitaskMultivariateNormal, MultivariateNormal
 from gpytorch.likelihoods.gaussian_likelihood import FixedNoiseGaussianLikelihood
-from gpytorch.utils.broadcasting import _mul_broadcast_shape
 from torch import Tensor
 
 
@@ -45,6 +44,8 @@ class GPyTorchModel(Model, ABC):
 
     The easiest way to use this is to subclass a model from a GPyTorch model
     class (e.g. an `ExactGP`) and this `GPyTorchModel`. See e.g. `SingleTaskGP`.
+
+    :meta private:
     """
 
     @staticmethod
@@ -214,6 +215,8 @@ class BatchedMultiOutputGPyTorchModel(GPyTorchModel):
 
     This model should be used when the same training data is used for all outputs.
     Outputs are modeled independently by using a different batch for each output.
+
+    :meta private:
     """
 
     _num_outputs: int
@@ -491,6 +494,8 @@ class ModelListGPyTorchModel(GPyTorchModel, ModelList, ABC):
 
     This is meant to be used with a gpytorch ModelList wrapper for independent
     evaluation of submodels.
+
+    :meta private:
     """
 
     @property
@@ -510,7 +515,7 @@ class ModelListGPyTorchModel(GPyTorchModel, ModelList, ABC):
                 "batch shapes"
             )
             try:
-                broadcast_shape = _mul_broadcast_shape(*batch_shapes)
+                broadcast_shape = torch.broadcast_shapes(*batch_shapes)
                 warnings.warn(msg + ". Broadcasting batch shapes.")
                 return broadcast_shape
             except RuntimeError:
@@ -620,6 +625,8 @@ class MultiTaskGPyTorchModel(GPyTorchModel, ABC):
 
     This class provides the `posterior` method to models that implement a
     "long-format" multi-task GP in the style of `MultiTaskGP`.
+
+    :meta private:
     """
 
     def posterior(
