@@ -27,6 +27,7 @@ from typing import Any, Dict, List, Optional, Tuple, Union
 import numpy as np
 import torch
 from botorch.acquisition.objective import PosteriorTransform
+from botorch.exceptions import UnsupportedError
 from botorch.models.likelihoods.pairwise import (
     PairwiseLikelihood,
     PairwiseProbitLikelihood,
@@ -40,14 +41,14 @@ from gpytorch.constraints import Positive
 from gpytorch.distributions.multivariate_normal import MultivariateNormal
 from gpytorch.kernels.rbf_kernel import RBFKernel
 from gpytorch.kernels.scale_kernel import ScaleKernel
-from gpytorch.lazy.lazy_tensor import LazyTensor
 from gpytorch.means.constant_mean import ConstantMean
 from gpytorch.mlls import MarginalLogLikelihood
 from gpytorch.models.gp import GP
 from gpytorch.module import Module
 from gpytorch.priors.smoothed_box_prior import SmoothedBoxPrior
 from gpytorch.priors.torch_priors import GammaPrior
-from gpytorch.utils.cholesky import psd_safe_cholesky
+from linear_operator.operators import LinearOperator
+from linear_operator.utils.cholesky import psd_safe_cholesky
 from scipy import optimize
 from torch import float32, float64, Tensor
 from torch.nn.modules.module import _IncompatibleKeys
@@ -56,14 +57,29 @@ from torch.nn.modules.module import _IncompatibleKeys
 class PairwiseGP(Model, GP):
     r"""Probit GP for preference learning with Laplace approximation
 
+    A probit-likelihood GP that learns via pairwise comparison data, using a
+    Laplace approximation of the posterior of the estimated utility values. By
+    default it uses a scaled RBF kernel.
+
     Implementation is based on [Chu2005preference]_.
     Also see [Brochu2010tutorial]_ for additional reference.
 
     Note that in [Chu2005preference]_ the likelihood of a pairwise comparison
     is :math:`\left(\frac{f(x_1) - f(x_2)}{\sqrt{2}\sigma}\right)`, i.e. a scale is
     used in the denominator. To maintain consistency with usage of kernels
-    elsewhere in botorch, we instead do not include :math:`\sigma` in the code
+    elsewhere in BoTorch, we instead do not include :math:`\sigma` in the code
     (implicitly setting it to 1) and use ScaleKernel to scale the function.
+
+    In the example below, the user/decision maker has stated that they prefer
+    the first item over the second item and the third item over the second item,
+    generating comparisons [0, 1] and [2, 1].
+
+    Example:
+        >>> from botorch.models import PairwiseGP
+        >>> import torch
+        >>> datapoints = torch.Tensor([[1, 2, 3], [4, 5, 6], [7, 8, 9]])
+        >>> comparisons = torch.Tensor([[0, 1], [2, 1]])
+        >>> model = PairwiseGP(datapoints, comparisons)
     """
 
     _buffer_names = [
@@ -88,9 +104,7 @@ class PairwiseGP(Model, GP):
         input_transform: Optional[InputTransform] = None,
         **kwargs,
     ) -> None:
-        r"""A probit-likelihood GP with Laplace approximation model that learns via
-            pairwise comparison data. By default it uses a scaled RBF kernel.
-
+        r"""
         Args:
             datapoints: A `batch_shape x n x d` tensor of training features.
             comparisons: A `batch_shape x m x 2` training comparisons;
@@ -218,10 +232,10 @@ class PairwiseGP(Model, GP):
             or self.comparisons is None
         )
 
-    def _calc_covar(self, X1: Tensor, X2: Tensor) -> Union[Tensor, LazyTensor]:
+    def _calc_covar(self, X1: Tensor, X2: Tensor) -> Union[Tensor, LinearOperator]:
         r"""Calculate the covariance matrix given two sets of datapoints"""
         covar = self.covar_module(X1, X2)
-        return covar.evaluate()
+        return covar.to_dense()
 
     def _batch_chol_inv(self, mat_chol: Tensor) -> Tensor:
         r"""Wrapper to perform (batched) cholesky inverse"""
@@ -253,7 +267,7 @@ class PairwiseGP(Model, GP):
         self.covar_chol = psd_safe_cholesky(self.covar)
         self.covar_inv = self._batch_chol_inv(self.covar_chol)
 
-    def _prior_mean(self, X: Tensor) -> Union[Tensor, LazyTensor]:
+    def _prior_mean(self, X: Tensor) -> Union[Tensor, LinearOperator]:
         r"""Return point prediction using prior only
 
         Args:
@@ -699,35 +713,49 @@ class PairwiseGP(Model, GP):
         self.to(self.datapoints)
 
     def load_state_dict(
-        self, state_dict: Dict[str, Tensor], strict: Optional[bool] = False
+        self, state_dict: Dict[str, Tensor], strict: bool = False
     ) -> _IncompatibleKeys:
         r"""Removes data related buffers from the `state_dict` and calls
         `super().load_state_dict` with `strict=False`.
 
         Args:
             state_dict: The state dict.
-            strict: A boolean denoting whether to error out if all keys are not
-                present in the `state_dict`. Since we remove data related buffers
-                from the `state_dict`, this will lead to an error whenever
-                `strict=True`. Instead, we overwrite it with `strict=False`, and
-                raise a warning explaining this if `strict=True` is passed.
+            strict: Boolean specifying whether or not given and instance-bound
+                state_dicts should have identical keys. Only implemented for
+                `strict=False` since buffers will filters out when calling
+                `_load_from_state_dict`.
 
         Returns:
             A named tuple `_IncompatibleKeys`, containing the `missing_keys`
-            and `unexpected_keys`. Note that the buffers we remove from the
-            `state_dict` may be listed under `missing_keys`.
+            and `unexpected_keys`.
         """
         if strict:
-            warnings.warn(
-                f"Received `strict=True` in {self.__class__.__name__}.load_state_dict "
-                "call. This will be overwritten with `strict=False` after removing "
-                "a set of data related buffers from the `state_dict`.",
-                RuntimeWarning,
-            )
-        for key in self._buffer_names:
-            state_dict.pop(key, None)
+            raise UnsupportedError("Passing strict=True is not supported.")
+
         return super().load_state_dict(state_dict=state_dict, strict=False)
 
+    def _load_from_state_dict(
+        self,
+        state_dict: Dict[str, Tensor],
+        prefix: str,
+        local_metadata: Dict[str, Any],
+        strict: bool,
+        missing_keys: List[str],
+        unexpected_keys: List[str],
+        error_msgs: List[str],
+    ) -> None:
+        super()._load_from_state_dict(
+            state_dict={
+                k: v for k, v in state_dict.items() if k not in self._buffer_names
+            },
+            prefix=prefix,
+            local_metadata=local_metadata,
+            strict=False,
+            missing_keys=missing_keys,
+            unexpected_keys=unexpected_keys,
+            error_msgs=error_msgs,
+        )
+
     def forward(self, datapoints: Tensor) -> MultivariateNormal:
         r"""Calculate a posterior or prior prediction.
 
@@ -943,6 +971,14 @@ class PairwiseLaplaceMarginalLogLikelihood(MarginalLogLikelihood):
     See (12) from [Chu2005preference]_.
     """
 
+    def __init__(self, likelihood, model: GP):
+        """
+        Args:
+            likelihood: Used as in args to GPyTorch MarginalLogLikelihood
+            model: Used as in args to GPyTorch MarginalLogLikelihood
+        """
+        super().__init__(likelihood, model)
+
     def forward(self, post: Posterior, comp: Tensor) -> Tensor:
         r"""Calculate approximated log evidence, i.e., log(P(D|theta))
 
